# openai-playground

## Introduction

Use other openai-compatible API services in OpenAI Playground.

It supports:

- Add any openai-compatible API service.
- In stream mode.
- History chatting storage and export.

This is a useful tool for those AI services that have awful playground experience.

#### Demo:

<img src="resources/demo_2x_speed.gif">

## Installation

```bash
pip install openai-playground
```